import json
import os
from typing import Any, Optional
from zipfile import ZipFile

import pytest
from click.testing import CliRunner

from gcs_migration.commands.gcs_migration import main
from gcs_migration.models import MigrationPlan


@pytest.mark.parametrize("description", [None, "This is a snapshot"])
def test_snapshot_create(
    migration_plan: MigrationPlan,
    fs: Any,
    description: Optional[str],
) -> None:
    migration_plan.dump()

    runner = CliRunner()
    args = ["snapshot", "create"]

    if description is not None:
        args.extend(["-d", description])

    os.mkdir("migration_snapshots")
    with open("migration_snapshots/0009", "w"):
        pass

    result = runner.invoke(main, args, catch_exceptions=False)
    assert result.exit_code == 0

    assert os.path.exists("migration_snapshots/0010")

    with ZipFile("migration_snapshots/0010", "r") as z:
        with z.open("metadata.json", "r") as mf:
            metadata = json.load(mf)
            assert metadata.get("description") == description
            for n in z.namelist():
                if n != "metadata.json":
                    assert os.path.exists(n)
