import pytest

from gcs_migration.typing.auth_documents import (
    IdentityDocumentDict,
    IdentityProviderDocumentDict,
)


@pytest.fixture
def globus_identity_provider_document() -> IdentityProviderDocumentDict:
    return {
        "id": "d51f5c44-a53b-4d47-ac95-283a4a4643f5",
        "name": "Globus Staff",
        "short_name": "globus.org",
        "alternative_names": [],
        "domains": ["globus.org"],
    }


@pytest.fixture
def identity_document(
    globus_identity_provider_document: IdentityProviderDocumentDict,
) -> IdentityDocumentDict:
    return {
        "username": "user@globus.org",
        "status": "used",
        "name": "User Identity Document",
        "id": "64620d3a-f6d6-4e56-9b48-a73b3ac5f070",
        "organization": "Globus",
        "email": "user_email@globus.org",
        "identity_type": "login",
        "identity_provider": "f{globus_identity_provider_document['id']}",
    }


@pytest.fixture
def unused_idp_identity_document(
    globus_identity_provider_document: IdentityProviderDocumentDict,
) -> IdentityDocumentDict:
    return {
        "username": "ununsed@globus.org",
        "status": "unused",
        "name": "Unused Identity Document",
        "id": "5a692aaa-c14b-4cb2-b8b0-b23721963693",
        "identity_type": "login",
        "organization": "Globus",
        "email": "unused_email@globus.org",
        "identity_provider": "f{globus_identity_provider_document['id']}",
    }


@pytest.fixture
def closed_idp_identity_document(
    globus_identity_provider_document: IdentityProviderDocumentDict,
) -> IdentityDocumentDict:
    return {
        "username": "closed@globus.org",
        "status": "closed",
        "name": "Closed Identity Document",
        "id": "759082d1-2ab2-4aa8-9686-b4d1efb32f37",
        "identity_type": "login",
        "organization": "Globus",
        "email": "closed_email@globus.org",
        "identity_provider": "f{globus_identity_provider_document['id']}",
    }


@pytest.fixture
def sharing_local_identity_document(
    globus_identity_provider_document: IdentityProviderDocumentDict,
    sharing_local_user: str,
) -> IdentityDocumentDict:
    return {
        "username": f"{sharing_local_user}@globus.org",
        "status": "used",
        "name": "Sharing User Identity Document",
        "id": "ff1f0c05-8518-413b-b863-5089f8f926a4",
        "organization": "Globus",
        "email": "sharing_email@globus.org",
        "identity_type": "login",
        "identity_provider": "f{globus_identity_provider_document['id']}",
    }


@pytest.fixture
def email_identity_provider_document() -> IdentityProviderDocumentDict:
    return {
        "id": "7daddf46-70c5-45ee-9f0f-7244fe7c8707",
        "name": "Email Address",
        "short_name": "email.org",
        "alternative_names": [],
        "domains": ["email.org"],
    }


@pytest.fixture
def email_idp_identity_document(
    email_identity_provider_document: IdentityProviderDocumentDict,
) -> IdentityDocumentDict:
    return {
        "username": "user@email.org",
        "status": "used",
        "name": "Email Identity Document",
        "id": "945247fb-a748-4cac-9c52-2c81ec05582a",
        "identity_type": "email",
        "organization": "Globus",
        "email": "user_email@globus.org",
        "identity_provider": "f{email_identity_provider_document['id']}",
    }


@pytest.fixture
def example_identity_provider_document() -> IdentityProviderDocumentDict:
    return {
        "id": "16976f71-db9c-43b2-a933-a530f8b7b97f",
        "name": "Example IdP",
        "short_name": "example",
        "alternative_names": [],
        "domains": ["example.org"],
    }
